# Mueller_et_al_2024_Observational_avoidance

This repository contains data and code to reproduce the results of "Observational threat learning influences costly avoidance behavior in healthy humans" by Madeleine Mueller, Oded Cohen, Tomer Shechner & Jan Haaker.


contents:
1. study overview
2. data tables 
3. scripts used for analysis

###############################
###### 1. study overview ######
###############################
Observational threat learning influences costly avoidance behaviour in healthy humans
Madeleine Mueller, Oded Cohen, Tomer Shechner & Jan Haaker


Stimulus materials
Stimulus materials included pictures of yellow or blue doorbells serving as conditioned stimuli (CSs), as per Skversky-Blocq et al. (2021). The colors of the CS+ and CS- were counterbalanced. Hereafter, we will refer to the directly presented stimuli as 'CS' and to the observational stimuli (video) as 'OCS.' Similarly, an observational unconditioned stimulus will be denoted as 'OUS.' OCSs were presented in 12-second videos featuring a male demonstrator wearing headphones, looking at a monitor displaying either the CS+ or the CS-. The onset of the OUS was indicated by the demonstrator's facial reaction to an unpleasant sound, occurring seven seconds into the video and lasting one second. Generalized stimuli comprised five doorbells with a color gradient ranging from yellow to blue, following the methodology of Skversky-Blocq et al. (2021).

Experimental procedure
Observational learning took place in this online study, with participants completing questionnaires (State-trait anxiety inventory (STAI-S/STAI-T), administered via www.soscisurvey.de) on day one, followed by the observational learning task (conducted using PsychoPy3). During this task, participants observed a demonstrator completing two blocks of threat learning, each consisting of six presentations of observational conditioned stimuli (OCS) per block (3xOCS-; 2xOCS+ reinforced; 1xOCS+ not reinforced), totaling 12 trials (6xOCS+, 6xOCS-) with a reinforcement rate of 66%. The stimulus order was predetermined for the two blocks, but the block order was randomized. After each OCS presentation, an intertrial interval (ITI) was presented with a randomized duration between 4 to 6 seconds. Participants were asked to rate their discomfort, fear, and physical arousal towards the CS+ and CS- using a visual analogue scale ranging from 0 (no discomfort) to 10 (much discomfort), with similar scales for fear and physical arousal, both before and after the learning phase.
On day 2 (approximately 24 hours after day 1), participants completed the STAI-S again, followed by a direct generalization task. The results of the generalization task are not discussed here, as they are part of a separate project conducted with a different sample. Before the generalization task, participants were instructed to wear headphones and informed that they might hear an unpleasant sound (US). They were instructed to adjust their computer volume to the maximum setting, and a test sound ('beep') was played. If they couldn't hear the sound, they were asked to check their headphones and volume settings and retry the test until they could hear the sound. However, during the subsequent task, no aversive sound was actually presented. The generalization task consisted of three blocks where five generalization stimuli (GS), along with the two learned CSs, were presented pseudo-randomly. Following each CS and GS presentation, an ITI was presented with a randomized duration between 4 to 6 seconds. Before the second and third blocks, two videos displaying the reinforced OCS+ and the OCS- were shown as a reminder. During each CS/GS presentation, participants rated how safe/dangerous they perceived their situation when confronted with the respective stimulus on a scale of 1 to 4 (1 = safe, 4 = dangerous). Before and after the generalization task, participants were again asked to rate their discomfort, fear, and physical arousal.

Behavioural Translation/Avoidance task. After completing the generalization task on day 2, participants proceeded to engage in the behavioral translation/avoidance task while continuing to wear the headphones used in the previous task. The task was presented in an 8x8 tile grid, with participants initiating each trial from one of the bottom corners and aiming to reach a tile labeled 'goal' situated in the opposite top corner. Movement between tiles was achieved by clicking on adjacent tiles, each indicated by a black circle. In row 5 of the grid, a fence barrier impeded progress, featuring only two doors for passage. One door contained the CS+ doorbell, while the other held the CS- doorbell. Participants were free to choose which door to pass through in their attempt to reach the goal. Clicking on a tile with a fence triggered a warning sign stating 'stop climbing over the fences,' instructing participants to navigate through the grid from the starting point to the goal while avoiding tiles with fences. It's important to note that choosing the CS- door required additional effort, as participants had to take at least one extra step (requiring one more mouse click) compared to a route that included the CS+ door. Two different path directions were utilized (starting from bottom left to goal top right and starting from bottom right to goal top left) across two path lengths (short path length involving the shortest route through the CS+ door with 7 steps and long path length with 8 steps). Participants completed each of these four versions (left to right/short path length, left to right/long path length, right to left/short path length, right to left/long path length) in a pseudo-randomized order, with five repetitions of each version (20 trials in total). To monitor participants' movements within the grid, we recorded the coordinates of each position, enabling us to track the number of steps taken to reach the goal and which door was selected for passage. Additionally, we logged the reaction time for each step.

Participants
For this online study, we recruited healthy individuals aged 18 to 65 years until we reached our pre-registered sample size of over 89 participants for the observational learning task (one additional participant was excluded from the avoidance task due to technical issues). Participation required access to a computer with headphones. Participants were excluded from analysis if they did not complete all three parts of the study (observational learning, direct generalization, and behavioral translation/avoidance tasks), or if the time between the observational learning (ACQ on day 1) and generalization (GEN on day 2) tasks was less than 18 hours or more than 30 hours (i.e., 24 hours ±6 hours). Additionally, participants who consistently rated all stimuli as safe or dangerous on day 2 (i.e., clicked through uniformly) were excluded from analysis.
Initially, 153 participants were recruited. After applying the exclusion criteria, the final sample size comprised 89 participants (65 female, 23 male, 1 diverse). Participation was remunerated with €10. Participants provided demographic information including age (mean age = 27.73 years, sd = 5.584, min=19 years, max=53 years), gender, alcohol consumption (mean alcohol consumption = 1.053 units per week, sd = 1.583, min = 0/week, max = 8/week), coffee consumption (mean coffee consumption = 1.25 units per day, sd = 1.09, min = 0/day, max = 5/day), and smoking status (78 non-smokers, 11 smokers). They also completed the Trait Anxiety Inventory (STAI-T), the State Anxiety Inventory (STAI-S) [Spielberger, 1983], and a questionnaire regarding their physical activity. Smokers additionally answered the Fagerström questionnaire for nicotine dependence.


###############################
######## 2. data tables #######
###############################

"d1_FearRating.csv"
a high rating value indicates strong discomfort, high fear or high physical arousal towards the specific stimulus (Visual Analogue Scale 0(low)-10(high))
variables:
	>sub = subject code/number	
	>prepost = time of rating, =1 before ACQ, =2 after ACQ	
	>stim = stimulus, CSP=CS+, CSM=CS-
	>disc_rat = discomfort rating
	>fear_rat = fear rating
	>phys_rat = physical arousal rating

"d2_Fear_Ratings.xls"
a high rating value indicates strong discomfort, high fear or high physical arousal towards the specific stimulus (Visual Analogue Scale 0(low)-10(high))
variables:
	>sub = subject code/number	
	>prepost = time of rating, =1 before GEN, =2 after GEN	
	>stim = stimulus, CSP=CS+, CSM=CS-
	>disc_rat = discomfort rating
	>fear_rat = fear rating
	>phys_rat = physical arousal rating

"d2_Safe_Ratings.csv"
a high rating value indicates high danger assessment towards the specific stimulus (Visual Analogue Scale discrete steps 1(safe)-4(dangerous))
variables:
	>sub = subject code/number
	>block = block number (1-3)
	>stim = stimulus CSP = CS+, GS1 = generalised stimuli 1, GS2 = generalised stimuli 2, GS3 = generalised stimuli 3, GS4 = generalised stimuli 4, GS5 = generalised stimuli 5, CSM = CS- 
	>safe_rat = safe rating (1=safe, 4=dangerous)

"d2_avoidance.csv"
	>code = subject code/number
	>steps = total number of steps taken in that trial
	>pathlength = short path version=1/long path version=2
	>trial = trial number (1-20)
	>CS = which door was used in that trial; CS+=1, CS-=2, fence=3, both CS=4
	>wallfactor = each step was either=0, whenever participants moved directly by the wall and =1 if they moved through the remaining centre of the grid, then a mean for the whole trial was calculated, which is this wallfactor. i.e. that the more thigmotaxis (movement close to wall), the smaller the wallfactor for that trial

"d2_avoidance_reactiontime.csv"
	>code = subject code/number
	>Xgrid = x-coordinate in the grid (0=most left, 7=most right)
	>Ygrid = y-coordinate in the grid (0=most down, 7=most up)
	>steps = step number on that x/y coordinate
	>pathlength = short path version=1/long path version=2
	>trial = trial number (1-20)
	>reactiontime = time spend on that x/y coordinate
	>prepost = position in grid (pre= before decision, dec= decision position on y=4, so on door/fence line, post= after decision)
	>CS = which door was used in that trial; CS+=1, CS-=2, fence=3, both CS=4
	
######################################
##### 3. scripts used for analysis ###
######################################

"rating_analysis_bothDays.R" = contains linear mixed effect models (lme4 package) and follow up ANOVAs and post-hoc tests of data for fear, discomfort and physical arousal ratings on both days, as well as safe/danger ratings of generalisation on day2

"avoidance_analysis.R" = contains linear mixed effect models (lme4 package) and follow up ANOVAs and post-hoc tests of data  for avoidance data general/stimulus difference analysis, mediation analysis and reactiontime